@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2022-04-19
+# Release 2022-11-11
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.6.0
+MAKERESOLVEDEB_VERSION=1.6.1
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -505,13 +505,14 @@ installer_extract_native() {
     # Extract archive
     echo "Extracting archive"
     createf_directory ${UNPACK_DIR}
+    UNPACK_DIR_ABS=$(cd "${UNPACK_DIR}"; pwd)
     chmod a+x ${INSTALLER_ARCHIVE}
     if [[ ! -x ${INSTALLER_ARCHIVE} ]];
     then
 	echo "[ERROR] DaVinci Resolve installer archive is not executable"
 	exit 1
     fi
-    NUMEXTRACT=$(./${INSTALLER_ARCHIVE} -i -y -n -C ${UNPACK_DIR} | grep "^Copied " -c)
+    NUMEXTRACT=$(./${INSTALLER_ARCHIVE} -i -y -n -C ${UNPACK_DIR_ABS} | grep "^Copied " -c)
     echo "Found ${NUMEXTRACT} objects"
     if [[ -z "$(ls -A ${UNPACK_DIR})" ]];
     then
